# Beginner Friendly Riot API Caller (bfrac)

This is a python wrapper for RiotAPI with rate maintenance built in.

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install bfrac
```
## License

MIT License

Copyright (c) 2023 Chathura Jayalath (deamonpog)